<?php
namespace Creativepricingtable;

use Creativepricingtable\PageSettings\Page_Settings;
define( "BWDPT_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDPT_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );

class ClassBWDPTpricing {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdpt_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdpt_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdpt_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdpt_the_pricing_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdpt-price.php' );
	}

	public function bwdpt_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDPTPricingTable() );
	}

	

	// Register Category
	function bwdpt_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdpt-pricing-table-category',
			[
				'title' => esc_html__( 'BWD Pricing Table', 'bwd-pricing-table' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdpt_all_assets_for_the_public(){
		wp_enqueue_style('bwdpt_pricing_fontAwesome', BWDPT_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/font-awesome.css', array(), '6.5.0', 'all');
		wp_enqueue_style('bwdpt_pricing_style', BWDPT_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/style.css', array(), '1.0', 'all');		
	}
	public function bwdpt_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdpt_pricing_admin_icon_css' => array('bwdpt_path_admin_define'=>BWDPT_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdpt_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdpt_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdpt_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdpt_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdpt_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdpt_admin_editor_scripts' ] );
	}
}

// Instantiate Plugin Class
ClassBWDPTpricing::instance();